@@ -8,29 +8,30 @@
 // <int>.<int>.<int>-<any text>.
 // or else upgrading old project file will not work
 // reliably.
-#define VERSION "3.0.3-Girona"
+#define VERSION "3.2.2-Bonn"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 303
-#define VERSION_INT 30003
-#define ABISYM(x) x ## 30003
+//#define VERSION_INT 322
+#define VERSION_INT 30202
+#define ABISYM(x) x ## 30202
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Girona"
+#define RELEASE_NAME "Bonn"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
 #define QGIS_LIBEXEC_SUBDIR "lib/qgis"
 #define QGIS_LIB_SUBDIR "lib"
+#define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr"
-#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.0.3"
+#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.2.2"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
-#define QSCINTILLA_VERSION_STR "2.10.4"
+#define QSCINTILLA_VERSION_STR "2.10.7"
 
 #if defined( __APPLE__ )
 //used by Mac to find system or bundle resources relative to amount of bundling
@@ -64,5 +65,7 @@
 
 /* #undef QGISDEBUG */
 
+/* #undef HAVE_QUICK */
+
 #endif
 
