@@ -23,10 +23,11 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
 
 
-from qgis.core import (QgsProcessingParameterVectorLayer,
+from qgis.core import (QgsProcessingException,
+                       QgsProcessingParameterVectorLayer,
                        QgsProcessingParameterBoolean,
                        QgsProcessingParameterFileDestination)
 from processing.algs.gdal.GdalAlgorithm import GdalAlgorithm
@@ -81,6 +82,9 @@ class ogrinfo(GdalAlgorithm):
             arguments.append('-nomd')
 
         inLayer = self.parameterAsVectorLayer(parameters, self.INPUT, context)
+        if inLayer is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
         connectionString = GdalUtils.ogrConnectionString(inLayer.source(), context)
         arguments.append(connectionString)
         return arguments
