@@ -23,11 +23,12 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
 
 import os
 from processing.tools.system import (isWindows, getTempFilename)
 from processing.algs.grass7.Grass7Utils import Grass7Utils
+from qgis.PyQt.QtCore import QDir
 from qgis.core import QgsProcessingParameterString
 from qgis.core import QgsMessageLog
 
@@ -168,10 +169,10 @@ def verifyRasterNum(alg, parameters, context, rasters, mini, maxi=None):
     """Verify that we have at least n rasters in multipleInput"""
     num = len(alg.parameterAsLayerList(parameters, rasters, context))
     if num < mini:
-        return 'You need to set at least {} input rasters for this algorithm!'.format(mini)
+        return False, 'You need to set at least {} input rasters for this algorithm!'.format(mini)
     if maxi and num > maxi:
-        return 'You need to set a maximum of {} input rasters for this algorithm!'.format(maxi)
-    return None
+        return False, 'You need to set a maximum of {} input rasters for this algorithm!'.format(maxi)
+    return True, None
 
 
 # def file2Output(alg, output):
@@ -191,9 +192,9 @@ def verifyRasterNum(alg, parameters, context, rasters, mini, maxi=None):
 def createDestDir(alg, toFile):
     """ Generates an mkdir command for GRASS7 script """
     # Creates the destination directory
-    command = "{} {}".format(
+    command = "{} \"{}\"".format(
         "MD" if isWindows() else "mkdir -p",
-        os.path.dirname(toFile)
+        QDir.toNativeSeparators(os.path.dirname(toFile))
     )
     alg.commands.append(command)
 
@@ -201,10 +202,10 @@ def createDestDir(alg, toFile):
 def moveFile(alg, fromFile, toFile):
     """ Generates a move command for GRASS7 script """
     createDestDir(alg, toFile)
-    command = "{} {} {}".format(
+    command = "{} \"{}\" \"{}\"".format(
         "MOVE /Y" if isWindows() else "mv -f",
-        fromFile,
-        toFile
+        QDir.toNativeSeparators(fromFile),
+        QDir.toNativeSeparators(toFile)
     )
     alg.commands.append(command)
 
@@ -212,8 +213,8 @@ def moveFile(alg, fromFile, toFile):
 def copyFile(alg, fromFile, toFile):
     """ Generates a copy command for GRASS7 script """
     createDestDir(alg, toFile)
-    command = "{} {} {}".format(
+    command = "{} \"{}\" \"{}\"".format(
         "COPY /Y" if isWindows() else "cp -f",
-        fromFile,
-        toFile)
+        QDir.toNativeSeparators(fromFile),
+        QDir.toNativeSeparators(toFile))
     alg.commands.append(command)
