@@ -23,7 +23,9 @@ __copyright__ = '(C) 2010, Michael Minn'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+
+from qgis.PyQt.QtCore import QCoreApplication
 
 from qgis.core import (QgsProcessingParameterField,
                        QgsProcessing,
@@ -68,13 +70,22 @@ class DeleteColumn(QgisFeatureBasedAlgorithm):
 
     def prepareAlgorithm(self, parameters, context, feedback):
         self.fields_to_delete = self.parameterAsFields(parameters, self.COLUMNS, context)
-        return True
+
+        source = self.parameterAsSource(parameters, 'INPUT', context)
+        if source is not None:
+            for f in self.fields_to_delete:
+                index = source.fields().lookupField(f)
+                if index < 0:
+                    feedback.pushInfo(QCoreApplication.translate('DeleteColumn', 'Field “{}” does not exist in input layer').format(f))
+
+        return super().prepareAlgorithm(parameters, context, feedback)
 
     def outputFields(self, input_fields):
         # loop through twice - first we need to build up a list of original attribute indices
         for f in self.fields_to_delete:
             index = input_fields.lookupField(f)
-            self.field_indices.append(index)
+            if index >= 0:
+                self.field_indices.append(index)
 
         # important - make sure we remove from the end so we aren't changing used indices as we go
         self.field_indices.sort(reverse=True)
