@@ -23,21 +23,25 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
+__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
 
 import os
+import math
 
 from qgis.PyQt.QtGui import QIcon
 from qgis.PyQt.QtCore import QVariant
 
 from qgis.core import (NULL,
+                       QgsApplication,
                        QgsCoordinateTransform,
                        QgsField,
                        QgsFields,
                        QgsWkbTypes,
+                       QgsPointXY,
                        QgsFeatureSink,
                        QgsDistanceArea,
                        QgsProcessingUtils,
+                       QgsProcessingException,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterEnum,
                        QgsProcessingParameterFeatureSink)
@@ -55,10 +59,13 @@ class ExportGeometryInfo(QgisAlgorithm):
     OUTPUT = 'OUTPUT'
 
     def icon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'ftools', 'export_geometry.png'))
+        return QgsApplication.getThemeIcon("/algorithms/mAlgorithmAddGeometryAttributes.svg")
+
+    def svgIconPath(self):
+        return QgsApplication.iconPath("/algorithms/mAlgorithmAddGeometryAttributes.svg")
 
     def tags(self):
-        return self.tr('export,add,information,measurements,areas,lengths,perimeters,latitudes,longitudes,x,y,z,extract,points,lines,polygons').split(',')
+        return self.tr('export,add,information,measurements,areas,lengths,perimeters,latitudes,longitudes,x,y,z,extract,points,lines,polygons,sinuosity,fields').split(',')
 
     def group(self):
         return self.tr('Vector geometry')
@@ -86,10 +93,13 @@ class ExportGeometryInfo(QgisAlgorithm):
         return 'exportaddgeometrycolumns'
 
     def displayName(self):
-        return self.tr('Export geometry columns')
+        return self.tr('Add geometry attributes')
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
         method = self.parameterAsEnum(parameters, self.METHOD, context)
 
         wkb_type = source.wkbType()
@@ -101,6 +111,9 @@ class ExportGeometryInfo(QgisAlgorithm):
             new_fields.append(QgsField('perimeter', QVariant.Double))
         elif QgsWkbTypes.geometryType(wkb_type) == QgsWkbTypes.LineGeometry:
             new_fields.append(QgsField('length', QVariant.Double))
+            if not QgsWkbTypes.isMultiType(source.wkbType()):
+                new_fields.append(QgsField('straightdis', QVariant.Double))
+                new_fields.append(QgsField('sinuosity', QVariant.Double))
         else:
             new_fields.append(QgsField('xcoord', QVariant.Double))
             new_fields.append(QgsField('ycoord', QVariant.Double))
@@ -114,6 +127,8 @@ class ExportGeometryInfo(QgisAlgorithm):
         fields = QgsProcessingUtils.combineFields(fields, new_fields)
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
                                                fields, wkb_type, source.sourceCrs())
+        if sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
         coordTransform = None
 
@@ -181,7 +196,17 @@ class ExportGeometryInfo(QgisAlgorithm):
         return attrs
 
     def line_attributes(self, geometry):
-        return [self.distance_area.measureLength(geometry)]
+        if geometry.isMultipart():
+            return [self.distance_area.measureLength(geometry)]
+        else:
+            curve = geometry.constGet()
+            p1 = curve.startPoint()
+            p2 = curve.endPoint()
+            straight_distance = self.distance_area.measureLine(QgsPointXY(p1), QgsPointXY(p2))
+            sinuosity = curve.sinuosity()
+            if math.isnan(sinuosity):
+                sinuosity = NULL
+            return [self.distance_area.measureLength(geometry), straight_distance, sinuosity]
 
     def polygon_attributes(self, geometry):
         area = self.distance_area.measureArea(geometry)
