@@ -23,7 +23,7 @@ __copyright__ = '(C) 2010, Michael Minn'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
 
 from qgis.core import (QgsFeature,
                        QgsGeometry,
@@ -77,6 +77,9 @@ class GeometryConvert(QgisAlgorithm):
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
         index = self.parameterAsEnum(parameters, self.TYPE, context)
 
         if index == 0:
@@ -108,6 +111,8 @@ class GeometryConvert(QgisAlgorithm):
 
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
                                                source.fields(), newType, source.sourceCrs())
+        if sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
         features = source.getFeatures()
         total = 100.0 / source.featureCount() if source.featureCount() else 0
