@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
 
 import os
 import math
@@ -31,7 +31,8 @@ import math
 from qgis.PyQt.QtGui import QIcon
 from qgis.PyQt.QtCore import QVariant
 
-from qgis.core import (QgsFeatureRequest,
+from qgis.core import (QgsApplication,
+                       QgsFeatureRequest,
                        QgsField,
                        QgsFields,
                        QgsProject,
@@ -41,6 +42,7 @@ from qgis.core import (QgsFeatureRequest,
                        QgsFeatureSink,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessing,
+                       QgsProcessingException,
                        QgsProcessingParameterEnum,
                        QgsProcessingParameterField,
                        QgsProcessingParameterNumber,
@@ -63,7 +65,10 @@ class PointDistance(QgisAlgorithm):
     OUTPUT = 'OUTPUT'
 
     def icon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'ftools', 'matrix.png'))
+        return QgsApplication.getThemeIcon("/algorithms/mAlgorithmDistanceMatrix.svg")
+
+    def svgIconPath(self):
+        return QgsApplication.iconPath("/algorithms/mAlgorithmDistanceMatrix.svg")
 
     def group(self):
         return self.tr('Vector analysis')
@@ -108,8 +113,14 @@ class PointDistance(QgisAlgorithm):
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
         source_field = self.parameterAsString(parameters, self.INPUT_FIELD, context)
         target_source = self.parameterAsSource(parameters, self.TARGET, context)
+        if target_source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.TARGET))
+
         target_field = self.parameterAsString(parameters, self.TARGET_FIELD, context)
         same_source_and_target = parameters[self.INPUT] == parameters[self.TARGET]
         matType = self.parameterAsEnum(parameters, self.MATRIX_TYPE, context)
@@ -160,6 +171,8 @@ class PointDistance(QgisAlgorithm):
         out_wkb = QgsWkbTypes.multiType(source.wkbType()) if matType == 0 else source.wkbType()
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
                                                fields, out_wkb, source.sourceCrs())
+        if sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
         index = QgsSpatialIndex(target_source.getFeatures(QgsFeatureRequest().setSubsetOfAttributes([]).setDestinationCrs(source.sourceCrs(), context.transformContext())), feedback)
 
@@ -249,6 +262,8 @@ class PointDistance(QgisAlgorithm):
 
                 (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
                                                        fields, source.wkbType(), source.sourceCrs())
+                if sink is None:
+                    raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
             data = [inFeat[inField]]
             for target in target_source.getFeatures(QgsFeatureRequest().setSubsetOfAttributes([]).setFilterFids(featList).setDestinationCrs(source.sourceCrs(), context.transformContext())):
