@@ -2,7 +2,7 @@
 
 """
 ***************************************************************************
-    SpatialJoin.py
+    SpatialJoinSummary.py
     ---------------------
     Date                 : September 2017
     Copyright            : (C) 2017 by Nyall Dawson
@@ -23,7 +23,7 @@ __copyright__ = '(C) 2017, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
+__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
 
 import os
 
@@ -32,6 +32,7 @@ from collections import defaultdict
 from qgis.PyQt.QtGui import QIcon
 from qgis.PyQt.QtCore import QVariant
 from qgis.core import (NULL,
+                       QgsApplication,
                        QgsField,
                        QgsFields,
                        QgsFeatureSink,
@@ -43,6 +44,7 @@ from qgis.core import (NULL,
                        QgsStringStatisticalSummary,
                        QgsProcessing,
                        QgsProcessingUtils,
+                       QgsProcessingException,
                        QgsProcessingParameterBoolean,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterEnum,
@@ -64,9 +66,6 @@ class SpatialJoinSummary(QgisAlgorithm):
     DISCARD_NONMATCHING = "DISCARD_NONMATCHING"
     OUTPUT = "OUTPUT"
 
-    def icon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'ftools', 'join_location.png'))
-
     def group(self):
         return self.tr('Vector general')
 
@@ -76,6 +75,12 @@ class SpatialJoinSummary(QgisAlgorithm):
     def __init__(self):
         super().__init__()
 
+    def icon(self):
+        return QgsApplication.getThemeIcon("/algorithms/mAlgorithmBasicStatistics.svg")
+
+    def svgIconPath(self):
+        return QgsApplication.iconPath("/algorithms/mAlgorithmBasicStatistics.svg")
+
     def initAlgorithm(self, config=None):
         self.predicates = (
             ('intersects', self.tr('intersects')),
@@ -146,12 +151,19 @@ class SpatialJoinSummary(QgisAlgorithm):
 
     def tags(self):
         return self.tr(
-            "summary,aggregate,join,intersects,intersecting,touching,within,contains,overlaps,relation,spatial").split(
-            ',')
+            "summary,aggregate,join,intersects,intersecting,touching,within,contains,overlaps,relation,spatial,"
+            "stats,statistics,sum,maximum,minimum,mean,average,standard,deviation,"
+            "count,distinct,unique,variance,median,quartile,range,majority,minority,histogram,distinct").split(',')
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
         join_source = self.parameterAsSource(parameters, self.JOIN, context)
+        if join_source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.JOIN))
+
         join_fields = self.parameterAsFields(parameters, self.JOIN_FIELDS, context)
         discard_nomatch = self.parameterAsBool(parameters, self.DISCARD_NONMATCHING, context)
         summaries = [self.statistics[i][0] for i in
@@ -254,6 +266,8 @@ class SpatialJoinSummary(QgisAlgorithm):
 
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
                                                out_fields, source.wkbType(), source.sourceCrs())
+        if sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
         # do the join
         predicates = [self.predicates[i][0] for i in self.parameterAsEnums(parameters, self.PREDICATE, context)]
