@@ -23,20 +23,22 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
 
 import os
 import codecs
 
 from qgis.PyQt.QtGui import QIcon
 
-from qgis.core import (QgsCoordinateReferenceSystem,
+from qgis.core import (QgsApplication,
+                       QgsCoordinateReferenceSystem,
                        QgsWkbTypes,
                        QgsFeature,
                        QgsFeatureSink,
                        QgsFeatureRequest,
                        QgsFields,
                        QgsProcessing,
+                       QgsProcessingException,
                        QgsProcessingParameterField,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterFeatureSink,
@@ -60,7 +62,10 @@ class UniqueValues(QgisAlgorithm):
     OUTPUT_HTML_FILE = 'OUTPUT_HTML_FILE'
 
     def icon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'ftools', 'unique.png'))
+        return QgsApplication.getThemeIcon("/algorithms/mAlgorithmUniqueValues.svg")
+
+    def svgIconPath(self):
+        return QgsApplication.iconPath("/algorithms/mAlgorithmUniqueValues.svg")
 
     def group(self):
         return self.tr('Vector analysis')
@@ -92,6 +97,9 @@ class UniqueValues(QgisAlgorithm):
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
         field_names = self.parameterAsFields(parameters, self.FIELDS, context)
 
         fields = QgsFields()
